@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.5'
+    version = '1.0.6'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/cench/sentry-10-dingding'),
@@ -58,7 +58,7 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n > {device} \n\n > {uid} \n\n > {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > UID:{uid} \n\n > {path} \n\n [详细信息]({url})".format(
                     title=title,
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
